@@ -92,20 +92,20 @@ test_that("confusion measures", {
   expect_identical(FP, 2L)
   expect_identical(FN, 1L)
 
-  expect_identical(dor(response, truth, positive = "a"), (TP / FP) / (FN / TN))
-  expect_identical(fdr(response, truth, positive = "a"), FP / (TP + FP))
-  expect_identical(fnr(response, truth, positive = "a"), FN / (TP + FN))
-  expect_identical(fomr(response, truth, positive = "a"), FN / (FN + TN))
-  expect_identical(fpr(response, truth, positive = "a"), FP / (FP + TN))
-  expect_identical(mcc(response, truth, positive = "a"), (TP * TN - FP * FN) / sqrt((TP + FP) * (TP + FN) * (TN + FP) * (TN + FN)))
-  expect_identical(npv(response, truth, positive = "a"), TN / (FN + TN))
-  expect_identical(ppv(response, truth, positive = "a"), TP / (TP + FP))
-  expect_identical(precision(response, truth, positive = "a"), TP / (TP + FP))
-  expect_identical(recall(response, truth, positive = "a"), TP / (TP + FN))
-  expect_identical(sensitivity(response, truth, positive = "a"), TP / (TP + FN))
-  expect_identical(specificity(response, truth, positive = "a"), TN / (FP + TN))
-  expect_identical(tnr(response, truth, positive = "a"), TN / (FP + TN))
-  expect_identical(tpr(response, truth, positive = "a"), TP / (TP + FN))
+  expect_equal(dor(response, truth, positive = "a"), (TP / FP) / (FN / TN))
+  expect_equal(fdr(response, truth, positive = "a"), FP / (TP + FP))
+  expect_equal(fnr(response, truth, positive = "a"), FN / (TP + FN))
+  expect_equal(fomr(response, truth, positive = "a"), FN / (FN + TN))
+  expect_equal(fpr(response, truth, positive = "a"), FP / (FP + TN))
+  expect_equal(mcc(response, truth, positive = "a"), (TP * TN - FP * FN) / sqrt((TP + FP) * (TP + FN) * (TN + FP) * (TN + FN)))
+  expect_equal(npv(response, truth, positive = "a"), TN / (FN + TN))
+  expect_equal(ppv(response, truth, positive = "a"), TP / (TP + FP))
+  expect_equal(precision(response, truth, positive = "a"), TP / (TP + FP))
+  expect_equal(recall(response, truth, positive = "a"), TP / (TP + FN))
+  expect_equal(sensitivity(response, truth, positive = "a"), TP / (TP + FN))
+  expect_equal(specificity(response, truth, positive = "a"), TN / (FP + TN))
+  expect_equal(tnr(response, truth, positive = "a"), TN / (FP + TN))
+  expect_equal(tpr(response, truth, positive = "a"), TP / (TP + FN))
 })
 
 test_that("bbrier", {
